class Player

  attr_reader :x, :y, :health
  attr_accessor :kill_count

  def initialize(window, x, y)
    @window = window

    @angle = 90.0

    @speed = 3

    @fire_rate = 0.1
    @last_shot_at

    @kill_count = 0
    @health = 5

    @immune_for = 0.5 # seconds
    @last_hit_at = Time.now

    @x = x
    @y = y
  end

  def update(mouse_x, mouse_y)
    look_at(mouse_x, mouse_y)
  end

  def draw
    GraphicsManager.instance.draw :player, @x, @y, @angle
  end

  def fire
    if @last_shot_at && ((Time.now - @last_shot_at) < @fire_rate)
      return nil
    else
      @last_shot_at = Time.now
      SoundManager.instance.play(:shot)
      return Bullet.new(@window, @x, @y, @angle)
    end
  end

  def move_up
    @y -= @speed
  end

  def move_down
    @y += @speed
  end

  def move_left
    @x -= @speed
  end

  def move_right
    @x += @speed
  end

  def look_at(x, y)
    mouse_x = x || @window.width
    mouse_y = y || @y

    dx = mouse_x - @x
    dy = mouse_y - @y

    @angle = (Math.atan2(dy, dx) * 180 / Math::PI)
  end

  def hit(power)
    if (Time.now - @last_hit_at > @immune_for) && !killed?
      @health -= power
      @last_hit_at = Time.now
    end
  end

  def killed?
    @health <= 0
  end

  private
  def speed
    100
  end

end
