class Zombie

  attr_reader :x, :y, :angle, :power

  def initialize(window, x, y)
    @window = window
    @angle = 90.0

    @speed = 1.5

    @health = 3
    @power = 1

    @x = x
    @y = y
  end

  def update(player)
    look_at(player.x, player.y)
    # http://www.policyalmanac.org/games/aStarTutorial.htm
    @x += @speed * Math.cos(@angle * Math::PI / 180)
    @y += @speed * Math.sin(@angle * Math::PI / 180)
  end

  def look_at(x, y)
    player_x = x || @window.width
    player_y = y || @y

    dx = player_x - @x
    dy = player_y - @y

    @angle = (Math.atan2(dy, dx) * 180 / Math::PI)
  end

  def draw
    GraphicsManager.instance.draw :zombie, @x, @y, @angle
    # @image.draw_rot(@x, @y, 0, @angle)
  end

  def hit(power)
    SoundManager.instance.play(:zombie_hit)
    @health -= power
  end

  def killed?
    @health <= 0
  end

  def die
    SoundManager.instance.play(:zombie_dead)
  end

  def collide?(thing)
    dist = Gosu::distance(@x, @y, thing.x, thing.y)
    dist < (16 + 16) # radius + radius
  end

  def self.spawn_around(thing, count, window)
    zombies = []
    radius = window.width / 2

    count.times do |i|
      angle = rand(360) + ((360 / count) * i)

      x = thing.x + (radius + 64 * rand(5)) * Math.cos(angle * Math::PI / 180)
      y = thing.y + (radius + 64 * rand(5)) * Math.sin(angle * Math::PI / 180)
      zombies << Zombie.new(window, x, y)
    end

    return zombies
  end

end
